aboutsummaryrefslogtreecommitdiffstats
path: root/Source/SPTableView.m
diff options
context:
space:
mode:
Diffstat (limited to 'Source/SPTableView.m')
-rw-r--r--Source/SPTableView.m4
1 files changed, 2 insertions, 2 deletions
diff --git a/Source/SPTableView.m b/Source/SPTableView.m
index 58e2206e..a1e44fb6 100644
--- a/Source/SPTableView.m
+++ b/Source/SPTableView.m
@@ -59,8 +59,8 @@
NSInteger row = [self rowAtPoint:[self convertPoint:[event locationInWindow] fromView:nil]];
if(row >= 0 && row < [self numberOfRows]) {
- // Check for TablesList if right-click on header, then suppress context menu
- if([[[[self delegate] class] description] isEqualToString:@"TablesList"]) {
+ // Check for SPTablesList if right-click on header, then suppress context menu
+ if([[[[self delegate] class] description] isEqualToString:@"SPTablesList"]) {
if([NSArrayObjectAtIndex([[self delegate] valueForKeyPath:@"tableTypes"], row) integerValue] == -1)
return nil;
}